function LINE = fluteinterp(L,N,D)

% LINE = fluteinterp(L,N,D)
%
% Create Lagrange interpolator multiplier vector to extract fractional
% delay sample from an integer delay line vector.
%
% L:    Delay line length
% N:    Interpolator degree
% D:    Fraction delay, containing both integer and fractional parts
%
% LINE: Delay line multiplication vector

INT  = floor(D);   % Integer delay
FRA  = D - INT;    % Fractional delay

% If the interpolator degree is even and the fractional part is greater than
% 0.5, we must move the interpolator one step forward because even Langrange
% interpolators work best when the fractional part is between [-0.5 0.5].

if N/2 == round(N/2) & FRA > 0.5
  FRA = FRA - 1;
  INT = INT + 1;
end;

% Compute Langrange coefficients

LAGR = hlagr(N+1,FRA); % hlagr should be reimplemented

% Construct coefficient vector that can be multiplied with a delay line vector

BEGIN = INT - floor(N / 2) + 1;
END   = BEGIN + size(LAGR,2) - 1;

if BEGIN < 1 | END > L
  error('Invalid delay argument');
end

LINE = sparse(1,L);
LINE(BEGIN:END) = LAGR;

